---
name: Bug report
about: Report a bug
title: ''
labels: bug
assignees: ''

---

### Please read this first

- **Have you read the docs?**[Agents SDK docs](https://openai.github.io/openai-agents-python/)
- **Have you searched for related issues?** Others may have faced similar issues.

### Describe the bug
A clear and concise description of what the bug is.

### Debug information
- Agents SDK version: (e.g. `v0.0.3`)
- Python version (e.g. Python 3.10)

### Repro steps

Ideally provide a minimal python script that can be run to reproduce the bug.


### Expected behavior
A clear and concise description of what you expected to happen.
